@@ -23,9 +23,10 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <glib.h>
 
 #include "anthy.h"
-#include "cannadic.h"
+#include "dixchange.h"
 /* #include "intl.h" */
 
 struct _anthy_dic_api {
@@ -115,7 +116,7 @@ int read_anthy_priv_dic_list(word **head) {
 	   && anthy_dic_api.priv_dic_get_word(desc, 100)) {
 
 	    word_append(head, WORD_TYPE_ANTHY,
-			phon, desc, cclass_code, 
+			phon, desc, cclass_code,
 			anthy_dic_api.priv_dic_get_freq(),
 			0, NULL);
 	}
@@ -124,63 +125,34 @@ int read_anthy_priv_dic_list(word **head) {
     return 0;
 }
 
-char *find_substantive_code_from_flag(const int flag) {
-    int substantive_code_num;
-    int i;
-    char *code = NULL;
+GList *anthy_read_privatediclist(void) {
+    GList *list = NULL;
+    gchar euc_literal[100], euc_phonetic[100], euc_pos[100];
+    gchar *literal, *phonetic, *pos;
+    gchar cclass[100], score[100];
+    gint ret = 0, rbytes, wbytes;
 
-    substantive_code_num = sizeof(substantive_code)/sizeof(substantive_code[0]);
-    for(i = 0; i < substantive_code_num; i++) {
-	if(flag == substantive_code[i].flag) {
-	    code = strdup(substantive_code[i].code);
-	    break;
+    if(anthy_dic_api.priv_dic_select_first_entry() == -1) {
+	return NULL;
+    }
+
+    while(ret == 0) {
+	if(anthy_dic_api.priv_dic_get_index(euc_phonetic, 100)
+	   && anthy_dic_api.priv_dic_get_wtype(euc_pos, 100)
+	   && anthy_dic_api.priv_dic_get_word(euc_literal, 100)) {
+	    phonetic = g_convert(euc_phonetic, -1, "UTF-8", "EUC-JP", &rbytes, &wbytes, NULL);
+	    literal = g_convert(euc_literal, -1, "UTF-8", "EUC-JP", &rbytes, &wbytes, NULL);
+	    pos = g_convert(euc_pos, -1, "UTF-8", "EUC-JP", &rbytes, &wbytes, NULL);
+	    g_snprintf(score, 100, "%d", anthy_dic_api.priv_dic_get_freq());
+	    cclass[0] = '\0'; /* XXX */
+	    list = dixchange_append_word(list, literal, phonetic, pos, cclass, score);
+	    g_free(phonetic);
+	    g_free(literal);
+	    g_free(pos);
 	}
+	ret = anthy_dic_api.priv_dic_select_next_entry();
     }
-
-    return code;
-}
-
-char *find_adverb_code_from_flag(const int flag) {
-    int adverb_code_num;
-    int i;
-    char *code = NULL;
-
-    adverb_code_num = sizeof(adverb_code) / sizeof(adverb_code[0]);
-    for(i = 0; i < adverb_code_num; i++) {
-	if(flag == adverb_code[i].flag) {
-	    code = strdup(adverb_code[i].code);
-	    break;
-	}
-    }
-    return code;
-}
-
-char *find_hinshi_name_from_code(const char *code) {
-    char *hinshi = NULL;
-/* Need to be more smart */
-    if(strncmp(code, "#JNM", 4) == 0) {
-	hinshi = strdup("\xbf\xcd\xcc\xbe"); /* Zinmei */
-	return hinshi;
-    } else if(strncmp(code, "#CN", 3) == 0) {
-	hinshi = strdup("\xc3\xcf\xcc\xbe"); /* Chimei */
-	return hinshi;
-    }
-
-    switch(code[1]) {
-    case 'T':
-	hinshi = strdup("\xcc\xbe\xbb\xec"); /* Meishi */
-	break;
-    case 'F':
-	hinshi = strdup("\xc9\xfb\xbb\xec"); /* Fukushi */
-	break;
-    case 'K':
-	hinshi = strdup("\xb7\xc1\xcd\xc6\xbb\xec"); /* Keiyoushi */
-	break;
-    default:
-	hinshi = strdup("\xc6\xb0\xbb\xec"); /* Doushi */
-	break;
-    }
-    return hinshi;
+    return list;
 }
 
 int add_anthy_priv_dic_with_flags(char *phon, char *desc,
