@@ -24,12 +24,12 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
+#include <glib.h>
 #include "canna.h"
 
 static struct _canna_api RkFunc;
 static void   *canna_lib;
 static int     context_num;
-static void    parse_line(unsigned char *, word **);
 static void    canna_get_privatedicname(unsigned char **);
 
 int canna_init(char *cannahost) {
@@ -107,7 +107,7 @@ int canna_get_word_text_dic(unsigned char *dirname,
 		break;
 
 	    dicname_bk[0] = '\0';
-	    parse_line(buf, head);
+	    cannadic_parse_line(buf, head);
 	} while(ret >= 0);
     }
     if(ret < 0)
@@ -171,66 +171,47 @@ int canna_delete_dic(unsigned char *dicname, unsigned char *buf) {
     return ret;
 }
 
-static void parse_line(unsigned char *buf, word **head) {
-    /*
-     * cannadic format:
-     *
-     * phon cclass desc (desc desc ... ) (cclass desc (desc ...) ....)
-     *
-     * phon  : must
-     * cclass: at least 1 entry
-     * desc  : at least 1 entry
-     *
-     * cclass and desc must be associated with each other.
-     *
-     */
-    unsigned char phon[1024], desc[1024], cclass_code[1024];
-    int buflen;
-    int desc_flag = 0, cclass_flag = 1;
-    int i, j;
+GList *canna_read_privatediclist(void) {
+    struct passwd *pw;
+    char *username, *dirname;
+    char dir[] = ":user/";
+    char dicname = "user"; /* XXX */
+    GList *list = NULL;
+    unsigned char buf[1024];
+    unsigned char dicname_bk[256];
+    int ret = 0;
 
-    if(buf[0] == '\0')
-	return;
+    pw = getpwuid(getuid());
+    if(pw != NULL) {
+	username = strdup(pw->pw_name);
 
-    buflen = strlen(buf);
-
-    /* $BFI$_$r8!=P(B */
-    for(i = 0; i < buflen; i++) {
-	if(buf[i] == ' ') {
-	    phon[i] = '\0';
-	    i++;
-	    break;
-	}
-	phon[i] = buf[i];
-    }
-
-    for(j = 0 ; i <= buflen; i++, j++) {
-	if(buf[i] == '#') {
-	    cclass_flag = 1; desc_flag = 0;
-	}
-
-	if(buf[i] == ' '|| buf[i] == '\0') {
-	    if(cclass_flag == 0 && desc_flag == 1) {
-		desc[j] = '\0';
-		if(buf[i+1] == '#') {
-		    desc_flag = 0;
-		    cclass_flag = 1;
+	if(username != NULL) {
+	    int len;
+	    /* dirname := ":user/username" */
+	    len = strlen(dir) + strlen(username) + 1;
+	    dirname = malloc(sizeof(char) * len);
+	    if(dirname != NULL) {
+		snprintf(dirname, len, "%s%s", dir, username);
+		if(RkFunc.GetWordTextDic != NULL) {
+#ifndef HAVE_STRLCPY
+		    strncpy(dicname_bk, dicname, 256);
+		    dicname_bk[255] = '\0';
+#else
+		    strlcpy(dicname_bk, dicname, 256);
+#endif
+		    do {
+			ret = RkFunc.GetWordTextDic(context_num, dirname,
+						    dicname_bk, buf, 1024);
+			if(ret <= 0)
+			    break;
+			
+			dicname_bk[0] = '\0';
+			list = cannadic_parse_line_glist(buf, list);
+		    } while(ret >= 0);
 		}
-		word_append(head, WORD_TYPE_CANNA,
-			    phon, desc, cclass_code,
-			    0, 0, NULL);
-	    } else if(cclass_flag == 1 && desc_flag == 0) {
-		desc_flag = 1;
-		cclass_flag = 0;
-		cclass_code[j] = '\0';
-	    }
-	    j = -1;
-	} else {
-	    if(cclass_flag == 1 && desc_flag == 0) {
-		cclass_code[j] = buf[i];
-	    } else if (cclass_flag == 0 && desc_flag == 1) {
-		desc[j] = buf[i];
+		free(dirname);
 	    }
+	    free(username);
 	}
     }
 }
