@@ -27,19 +27,17 @@
 typedef struct _anthy_addwordpane {
     GtkWidget *pane;
 
-    GtkWidget *yomi;
-    GtkWidget *kanji;
-    GtkWidget *hinshi;
+    GtkWidget *phon;
+    GtkWidget *desc;
+    GtkWidget *optmenu_cclass_code;
+    GtkWidget *cclass_code;
     GtkWidget *freq;
 
-    GtkWidget *meishi_options[5];
-    GtkWidget *fukushi_options[4];
-
-    GtkWidget *touroku;
+    GtkWidget *add;
     GtkWidget *clear;
 } AnthyAddWordPane;
 
-int create_addwordpane(AnthyAddWordPane *);
+AnthyAddWordPane *anthy_addwordpane_new(void);
 int show_addwordpane(AnthyAddWordPane *);
 
 #endif /* __ANTHY_ADDWORDPANE_H__ */
