@@ -52,7 +52,7 @@ void create_anthycontainer(AnthyContainer *container) {
 			       label_addword);
 
     gtk_container_add(GTK_CONTAINER(container->container), (container->importwordpane)->pane);
-    label_importword = gtk_label_new(_("Import"));
+    label_importword = gtk_label_new(_("Import/Export"));
     gtk_widget_show(label_importword);
     gtk_notebook_set_tab_label(GTK_NOTEBOOK(container->container),
 			       gtk_notebook_get_nth_page(GTK_NOTEBOOK(container->container), 2),
