@@ -48,6 +48,7 @@ static void cb_browse_button_clicked(GtkButton *button, GtkEntry *entry) {
     const gchar *filename;
     
     filebrowser = gtk_file_selection_new(_("Select File"));
+    gtk_window_set_position(GTK_WINDOW(filebrowser), GTK_WIN_POS_CENTER);
     ret = gtk_dialog_run(GTK_DIALOG(filebrowser));
 
     switch(ret) {
@@ -86,6 +87,7 @@ static void cb_export_button_clicked(GtkButton *button, AnthyImportWordPane *pan
 					GTK_MESSAGE_ERROR,
 					GTK_BUTTONS_CLOSE,
 					_("Exportion failed."));
+	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
     }
