@@ -27,11 +27,17 @@
 typedef struct _anthy_imortwordpane {
 	GtkWidget *pane;
 
+	/* Import */
 	GtkWidget *importfilename;
-	GtkWidget *button_getfilename;
-
+	GtkWidget *button_import_getfilename;
 	GtkWidget *button_doimport;
-	GtkWidget *button_clear;
+	GtkWidget *opt_dic_import_type;
+
+	/* Export */
+	GtkWidget *exportfilename;
+	GtkWidget *button_export_getfilename;
+	GtkWidget *button_doexport;
+	GtkWidget *opt_dic_export_type;
 } AnthyImportWordPane;
 
 int create_anthy_importwordpane(AnthyImportWordPane *pane);
