@@ -126,7 +126,7 @@ static void cb_anthy_bt_delete(GtkButton *button, AnthyViewWordPane *pane) {
     free(code);
 /* End of TODO */
 
-    if(!ret) {
+    if(ret) {
 	dialog = gtk_message_dialog_new(NULL,
 					GTK_DIALOG_MODAL,
 					GTK_MESSAGE_INFO,
@@ -139,7 +139,7 @@ static void cb_anthy_bt_delete(GtkButton *button, AnthyViewWordPane *pane) {
 					GTK_BUTTONS_CLOSE,
 					_("Word deletion failed."));
     }
-
+    gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
 
@@ -158,9 +158,9 @@ static void cb_anthy_bt_edit(GtkButton *button, AnthyViewWordPane *pane) {
     word *data;
     gchar freq_str[6];
     gint result;
-    const gchar *utf8_phon, *utf8_desc;
+    const gchar *utf8_phonetic, *utf8_literal;
     const gchar *cclass_code;
-    char *euc_phon, *euc_desc;
+    char *euc_phonetic, *euc_literal;
     int freq, ret;
 
     selected_data = wordlist_view_get_selected_data_list(WORDLIST_VIEW(pane->wordlist_anthy));
@@ -176,8 +176,8 @@ static void cb_anthy_bt_edit(GtkButton *button, AnthyViewWordPane *pane) {
 					 GTK_STOCK_CANCEL,
 					 GTK_RESPONSE_REJECT,
 					 NULL);
-    gtk_widget_set_size_request(GTK_WIDGET(dialog), 400, 200);
-
+ 
+    gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
     table = gtk_table_new(5, 2, FALSE);
     gtk_widget_show(table);
@@ -241,22 +241,32 @@ static void cb_anthy_bt_edit(GtkButton *button, AnthyViewWordPane *pane) {
 	ret = delete_anthy_priv_dic(data->phon, data->desc,
 				    data->cclass_code);
 
-	utf8_phon = gtk_entry_get_text(GTK_ENTRY(entry_phon));
-	utf8_desc = gtk_entry_get_text(GTK_ENTRY(entry_desc));
+	utf8_phonetic = gtk_entry_get_text(GTK_ENTRY(entry_phon));
+	utf8_literal = gtk_entry_get_text(GTK_ENTRY(entry_desc));
 	cclass_code = gtk_entry_get_text(GTK_ENTRY(entry_cclass_code));
 	freq = atoi(gtk_entry_get_text(GTK_ENTRY(entry_freq)));
 	
-	euc_phon = charset_convert(utf8_phon, "UTF-8", "EUC-JP");
-	euc_desc = charset_convert(utf8_desc, "UTF-8", "EUC-JP");
+	euc_phonetic = charset_convert(utf8_phonetic, "UTF-8", "EUC-JP");
+	euc_literal = charset_convert(utf8_literal, "UTF-8", "EUC-JP");
 
-	ret = add_anthy_priv_dic_with_flags(euc_phon, euc_desc,
-					    cclass_code, freq);
+	if(euc_phonetic != NULL && euc_literal != NULL) {
+	    ret = add_anthy_priv_dic_with_flags(euc_phonetic, euc_literal,
+						cclass_code, freq);
+	}
+
+	if(euc_phonetic != NULL)
+	    free(euc_phonetic);
+	if(euc_literal != NULL)
+	    free(euc_literal);
+	if(utf8_phonetic != NULL)
+	    g_free(utf8_phonetic);
+	if(utf8_literal != NULL)
+	    g_free(utf8_literal);
 	break;
     default:
 	break;
     }
 
-
     gtk_widget_destroy(dialog);
     g_list_free(selected_data);
 }
