@@ -449,21 +449,29 @@ static void cb_canna_viewwordpane_button_load_clicked(GtkButton *button,
 
     for(pos = list; pos != NULL; pos = pos->next) {
 /* for test */
-	gchar *eucjp_phon, *eucjp_desc, *eucjp_cclass_code;
-	eucjp_phon = pos->phon;
-	eucjp_desc = pos->desc;
-	eucjp_cclass_code = pos->cclass_code;
-	pos->phon = eucjp_to_utf8(eucjp_phon);
-	pos->desc = eucjp_to_utf8(eucjp_desc);
-	pos->cclass_code = eucjp_to_utf8(find_pos_from_code(eucjp_cclass_code, SUPPORT_CANNA));
+	gchar *eucjp_phonetic = NULL, *eucjp_literal = NULL;
+	gchar *eucjp_pos = NULL;
+
+	eucjp_phonetic = pos->phon;
+	eucjp_literal = pos->desc;
+	eucjp_pos = pos->cclass_code;
+	if(eucjp_phonetic != NULL)
+	    pos->phon = eucjp_to_utf8(eucjp_phonetic);
+	if(eucjp_literal != NULL)
+	    pos->desc = eucjp_to_utf8(eucjp_literal);
+	if(eucjp_pos != NULL)
+	    pos->cclass_code = eucjp_to_utf8(find_pos_from_code(eucjp_pos, SUPPORT_CANNA));
 
 	if(pos->phon != NULL && pos->desc != NULL &&
 	   pos->cclass_code != NULL) {
 	    wordlist_view_set_values(WORDLIST_VIEW(pane->wordlist_canna),
 				     pos);
-	    free(eucjp_phon);
-	    free(eucjp_desc);
-	    free(eucjp_cclass_code);
+	    if(eucjp_phonetic != NULL)
+		free(eucjp_phonetic);
+	    if(eucjp_literal != NULL)
+		free(eucjp_literal);
+	    if(eucjp_pos != NULL)
+		free(eucjp_pos);
 	}
     }
     word_free_list(list);
