@@ -44,17 +44,38 @@ typedef struct _canna_viewwordpane {
     GtkWidget *wordlist_canna;
     GtkWidget *button_load;
     GtkWidget *button_delete;
+
+    GtkWidget *searchword;
 } CannaViewWordPane;
 
+typedef struct _canna_imortwordpane {
+    GtkWidget *pane;
+
+    /* Import */
+    GtkWidget *importfilename;
+    GtkWidget *button_import_getfilename;
+    GtkWidget *button_doimport;
+    GtkWidget *opt_dic_import_type;
+    
+    /* Export */
+    GtkWidget *exportfilename;
+    GtkWidget *button_export_getfilename;
+    GtkWidget *button_doexport;
+    GtkWidget *opt_dic_export_type;
+} CannaImportWordPane;
+
+
 typedef struct _cannacontainer {
     GtkWidget *container; /* GtkNotebook */
 
     CannaViewWordPane *viewwordpane;
     CannaAddWordPane *addwordpane;
+    CannaImportWordPane *importwordpane;
 } CannaContainer;
 
 CannaAddWordPane *canna_addword_pane_new(void);
 CannaViewWordPane *canna_viewword_pane_new(void);
+CannaImportWordPane *canna_importword_pane_new(void);
 void show_canna_container(CannaContainer *container, gboolean flags);
 void create_canna_container(CannaContainer *container);
 #endif /* __CANNA_CONTAINER_H__ */
