@@ -182,7 +182,7 @@ static void wordlist_view_init(WordlistView *view) {
 						      "text", WORDLIST_WORD_TYPE,						      "editable", WORDLIST_EDITABLE,
 						      NULL);
 
-    gtk_tree_view_column_set_visible(column, TRUE);
+    gtk_tree_view_column_set_visible(column, FALSE);
     gtk_tree_view_append_column(view->view, column);
     view->word_type_column = column;
 
@@ -193,7 +193,7 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_PHON));
-    column = gtk_tree_view_column_new_with_attributes(_("Phon"), renderer,
+    column = gtk_tree_view_column_new_with_attributes(_("Phonetic"), renderer,
 						      "text", WORDLIST_PHON,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
@@ -208,7 +208,7 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_DESC));
-    column = gtk_tree_view_column_new_with_attributes(_("Description"),
+    column = gtk_tree_view_column_new_with_attributes(_("Literal"),
 						      renderer,
 						      "text", WORDLIST_DESC,
 						      "editable", WORDLIST_EDITABLE,
@@ -224,7 +224,7 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_CCLASS_CODE));
-    column = gtk_tree_view_column_new_with_attributes(_("Conjection Class Code"),
+    column = gtk_tree_view_column_new_with_attributes(_("Part of Speech"),
 						      renderer,
 						      "text", WORDLIST_CCLASS_CODE,
 						      "editable", WORDLIST_EDITABLE,
